@@ -48,7 +48,7 @@ class CircuitBreaker(
         '''
         props = CircuitBreakerProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(CircuitBreaker, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -174,7 +174,7 @@ class Dataplane(
         '''
         props = DataplaneProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(Dataplane, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -231,7 +231,7 @@ class DataplaneInsight(
         '''
         props = DataplaneInsightProps(mesh=mesh, metadata=metadata)
 
-        jsii.create(DataplaneInsight, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -409,7 +409,7 @@ class ExternalService(
         '''
         props = ExternalServiceProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(ExternalService, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -534,7 +534,7 @@ class FaultInjection(
         '''
         props = FaultInjectionProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(FaultInjection, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -660,7 +660,7 @@ class HealthCheck(
         '''
         props = HealthCheckProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(HealthCheck, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -784,7 +784,7 @@ class Mesh(
         '''
         props = MeshProps(metadata=metadata, spec=spec)
 
-        jsii.create(Mesh, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -841,7 +841,7 @@ class MeshInsight(
         '''
         props = MeshInsightProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(MeshInsight, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -1022,7 +1022,7 @@ class ProxyTemplate(
         '''
         props = ProxyTemplateProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(ProxyTemplate, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -1148,7 +1148,7 @@ class RateLimit(
         '''
         props = RateLimitProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(RateLimit, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -1274,7 +1274,7 @@ class Retry(
         '''
         props = RetryProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(Retry, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -1400,7 +1400,7 @@ class ServiceInsight(
         '''
         props = ServiceInsightProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(ServiceInsight, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -1526,7 +1526,7 @@ class Timeout(
         '''
         props = TimeoutProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(Timeout, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -1652,7 +1652,7 @@ class TrafficLog(
         '''
         props = TrafficLogProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(TrafficLog, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -1778,7 +1778,7 @@ class TrafficPermission(
         '''
         props = TrafficPermissionProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(TrafficPermission, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -1904,7 +1904,7 @@ class TrafficRoute(
         '''
         props = TrafficRouteProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(TrafficRoute, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -2030,7 +2030,7 @@ class TrafficTrace(
         '''
         props = TrafficTraceProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(TrafficTrace, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -2156,7 +2156,7 @@ class VirtualOutbound(
         '''
         props = VirtualOutboundProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(VirtualOutbound, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -2282,7 +2282,7 @@ class Zone(
         '''
         props = ZoneProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(Zone, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -2341,7 +2341,7 @@ class ZoneIngress(
         '''
         props = ZoneIngressProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(ZoneIngress, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -2400,7 +2400,7 @@ class ZoneIngressInsight(
         '''
         props = ZoneIngressInsightProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(ZoneIngressInsight, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
@@ -2593,7 +2593,7 @@ class ZoneInsight(
         '''
         props = ZoneInsightProps(mesh=mesh, metadata=metadata, spec=spec)
 
-        jsii.create(ZoneInsight, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="manifest") # type: ignore[misc]
     @builtins.classmethod
